bonndit\.michi package
======================

Submodules
----------

bonndit\.michi\.dwmri module
----------------------------

.. automodule:: bonndit.michi.dwmri
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.esh module
--------------------------

.. automodule:: bonndit.michi.esh
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.fields module
-----------------------------

.. automodule:: bonndit.michi.fields
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.nrrd module
----------------------------

.. automodule:: bonndit.michi.nrrd
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.shore module
----------------------------

.. automodule:: bonndit.michi.shore
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.storage module
------------------------------

.. automodule:: bonndit.michi.storage
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.tensor module
-----------------------------

.. automodule:: bonndit.michi.tensor
    :members:
    :undoc-members:
    :show-inheritance:

bonndit\.michi\.vector module
-----------------------------

.. automodule:: bonndit.michi.vector
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bonndit.michi
    :members:
    :undoc-members:
    :show-inheritance:
